@@ -1,4 +1,4 @@
-__version__ = "2.1.3"
+__version__ = "2.2.0"
 __author__ = "Hanjin Liu"
 __email__ = "liuhanjin-sc@g.ecc.u-tokyo.ac.jp"
 
@@ -11,7 +11,7 @@ from .core import *
 from .binder import bind
 from .viewer import gui
 from .correlation import *
-from .arrays import ImgArray, LazyImgArray, Label  # for typing
+from .arrays import ImgArray, LazyImgArray, BigImgArray, Label  # for typing
 from . import random, io
 from .axes import slicer
 
@@ -19,7 +19,7 @@ r"""
 Inheritance
 -----------
 
-AxesMixin -----> LazyImgArray
+AxesMixin -----> LazyImgArray ------> BigImgArray
     |
     +-----> MetaArray --+--> LabeledArray --+--> ImgArray
     |                   |                   |
