@@ -1,18 +1,23 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Iterable, Hashable, Union, SupportsInt, Mapping
+from typing import TYPE_CHECKING, Iterable, Hashable, Union, SupportsInt, Mapping, Any
 from pathlib import Path
 import numpy as np
 from numpy.typing import DTypeLike
-from ..axesmixin import AxesMixin
-from ..._types import *
-from ...axes import ImageAxesError, AxesLike, Axes
-from ...array_api import xp
-from ...utils import axesop, slicer
-from ...collections import DataList
+from impy._types import Callable, Slices
+from impy.axes import ImageAxesError, AxesLike, Axes, AxisLike
+from impy.array_api import xp
+from impy.utils import axesop, slicer
+from impy.collections import DataList
+from impy.arrays.axesmixin import AxesMixin
 
 if TYPE_CHECKING:
     from typing_extensions import Self
 
+try:
+    _NoValue = np._NoValue
+except AttributeError:
+    _NoValue = None  # simply avoid errors.
+
 SupportOneSlicing = Union[SupportsInt, slice]
 SupportSlicing = Union[
     SupportsInt,
@@ -95,7 +100,7 @@ class MetaArray(AxesMixin, np.ndarray):
     def __repr__(self) -> str:
         if self.ndim > 0:
             return super().__repr__()
-        return self.value[()]
+        return self.value.item()
 
     def _repr_dict_(self) -> dict[str, Any]:
         return {
@@ -140,7 +145,14 @@ class MetaArray(AxesMixin, np.ndarray):
         super().__setitem__(key, value)
     
     def sel(self, indexer=None, /, **kwargs: dict[str, Any]) -> Self:
-        """."""
+        """
+        A label based indexing method, mimicking ``xarray.sel``.
+        
+        Example
+        -------
+        >>> img.sel(c="Red")
+        >>> img.sel(t=slice("frame 3", "frame, 5"))
+        """
         if indexer is not None:
             kwargs.update(indexer)
         axes = self.axes
@@ -158,6 +170,14 @@ class MetaArray(AxesMixin, np.ndarray):
         return self[tuple(slices)]
     
     def isel(self, indexer=None, /, **kwargs: dict[str, Any]) -> Self:
+        """
+        A index based indexing method, mimicking ``xarray.isel``.
+        
+        Example
+        -------
+        >>> img.isel(c=3)
+        >>> img.isel(t=slice(4, 7))
+        """
         if indexer is not None:
             kwargs.update(indexer)
 
@@ -408,13 +428,17 @@ class MetaArray(AxesMixin, np.ndarray):
         
         return out
     
-    def transpose(self, axes) -> Self:
+    def transpose(self, axes=None) -> Self:
         """
         change the order of image dimensions.
         'axes' will also be arranged.
         """
-        _axes = [self.axisof(a) for a in axes]
-        new_axes = [self.axes[i] for i in list(axes)]
+        if axes is None:
+            _axes = None
+            new_axes = self.axes[::-1]
+        else:
+            _axes = [self.axisof(a) for a in axes]
+            new_axes = [self.axes[i] for i in list(axes)]
         out: np.ndarray = np.transpose(self.value, _axes)
         out = out.view(self.__class__)
         out._set_info(self, new_axes=new_axes)
@@ -502,6 +526,65 @@ class MetaArray(AxesMixin, np.ndarray):
             new_axes = axes
         out._set_info(self, new_axes=new_axes)
         return out
+    
+    def min(
+        self,
+        axis=None,
+        out: None = None,
+        keepdims: bool = _NoValue,
+        *,
+        where: np.ndarray = _NoValue,
+    ):
+        """Minimum value of the array along a given axis."""
+        return np.min(self, axis=axis, out=out, keepdims=keepdims, where=where)
+    
+    def max(
+        self,
+        axis=None,
+        out: None = None,
+        keepdims: bool = _NoValue,
+        *,
+        where: np.ndarray = _NoValue,
+    ):
+        """Maximum value of the array along a given axis."""
+        return np.max(self, axis=axis, out=out, keepdims=keepdims, where=where)
+    
+    def mean(
+        self,
+        axis=None,
+        dtype: DTypeLike = None,
+        out: None = None,
+        keepdims: bool = _NoValue,
+        *,
+        where: np.ndarray = _NoValue,
+    ):
+        """Mean value of the array along a given axis."""
+        return np.mean(self, axis=axis, dtype=dtype, out=out, keepdims=keepdims, where=where)
+    
+    def sum(
+        self,
+        axis=None,
+        dtype: DTypeLike = None,
+        out: None = None,
+        keepdims: bool = _NoValue,
+        *,
+        where: np.ndarray = _NoValue,
+    ):
+        """Sum value of the array along a given axis."""
+        return np.sum(self, axis=axis, dtype=dtype, out=out, keepdims=keepdims, where=where)
+    
+    def std(
+        self,
+        axis=None,
+        dtype: DTypeLike = None,
+        out: None = None,
+        ddof: int = 0,
+        keepdims: bool = _NoValue,
+        *,
+        where: np.ndarray = _NoValue,
+    ):
+        """Standard deviation of the array along a given axis."""
+        return np.std(self, axis=axis, dtype=dtype, out=out, ddof=ddof, keepdims=keepdims, where=where)
 
     def _dimension_matches(self, array: MetaArray):
         """Check if dimension satisfies ``self <: array``."""
@@ -512,6 +595,54 @@ class MetaArray(AxesMixin, np.ndarray):
             for a in self.axes]
         )
         
+    def as_rgba(
+        self, 
+        cmap: str | Callable[[np.ndarray], np.ndarray],
+        *,
+        axis: AxisLike = "c",
+        clim: tuple[float, float] | None = None,
+        alpha: np.ndarray | None = None,
+    ) -> Self:
+        """
+        Convert array to an RGBA image with given colormap.
+
+        Parameters
+        ----------
+        cmap : str or callable
+            Colormap. Can be a string name of a colormap registered in vispy.
+        axis : AxisLike, default is "c"
+            The axis name used for the color axis.
+        clim : (float, float), optional
+            Contrast limits. If not given, the minimum and maximum values of the
+            array will be used.
+
+        Returns
+        -------
+        MetaArray
+            Colored image.
+        """
+        new_axes = self.axes + axis
+        if isinstance(cmap, str):
+            from vispy.color import get_colormap
+            
+            vispy_cmap = get_colormap(cmap)
+            
+            def cmap(arr):
+                out = vispy_cmap.map(arr)
+                return out.reshape(self.shape + (4,))
+            
+        if clim is None:
+            clim = self.min(), self.max()
+            
+        low, high = clim
+        input = (np.clip(self.value, low, high) - low) / (high - low)
+        from impy import asarray
+        output = asarray(cmap(input), axes=new_axes, like=self)
+        
+        if alpha is not None:
+            output["c=3"] = np.clip(alpha / alpha.max(), 0, 1)
+        return output
+        
     def __add__(self, value) -> Self:
         value = self._broadcast(value)
         return super().__add__(value)
@@ -640,7 +771,7 @@ class MetaArray(AxesMixin, np.ndarray):
         This is called in __array_ufunc__(). Unlike _set_info(), keyword `axis` must be
         considered because it changes `ndim`.
         """
-        if "axis" in kwargs.keys():
+        if "axis" in kwargs and "keepdims" not in kwargs:
             new_axes = obj.axes.drop(kwargs["axis"])
         else:
             new_axes = self._INHERIT
