@@ -1,34 +1,33 @@
 from __future__ import annotations
-from functools import wraps
-import os
+from functools import lru_cache, wraps
 import itertools
 from pathlib import Path
-from typing import Any, Callable, TYPE_CHECKING
+from typing import Any, Callable, TYPE_CHECKING, Sequence
 import numpy as np
 from numpy.typing import ArrayLike, DTypeLike
 from warnings import warn
 import tempfile
+import operator
 
 from .labeledarray import LabeledArray
 from .imgarray import ImgArray
 from .axesmixin import AxesMixin
-from ._utils._skimage import skres
 from ._utils import _misc, _transform, _structures, _filters, _deconv, _corr, _docs
 
-from ..utils.axesop import slice_axes, switch_slice, complement_axes, find_first_appeared
-from ..utils.deco import check_input_and_output_lazy, dims_to_spatial_axes, same_dtype
-from ..utils.misc import check_nd
-from ..utils import slicer
-from ..io import imsave
-from ..collections import DataList
+from impy.utils.axesop import slice_axes, switch_slice, complement_axes, find_first_appeared
+from impy.utils.deco import check_input_and_output_lazy, dims_to_spatial_axes, same_dtype
+from impy.utils.misc import check_nd
+from impy.utils import slicer
+from impy.io import imsave
+from impy.collections import DataList
 
-from .._types import nDFloat, Coords, Iterable, Dims, PaddingMode
-from ..axes import ImageAxesError
-from .._const import Const
-from ..array_api import xp
+from impy.axes import ImageAxesError, AxisLike
+from impy.array_api import xp
+from impy._types import nDFloat, Coords, Iterable, Dims, PaddingMode
+from impy._const import Const
 
 if TYPE_CHECKING:
-    from dask import array as da
+    from dask.array.core import Array as DaskArray
 
 
 class LazyImgArray(AxesMixin):
@@ -36,16 +35,16 @@ class LazyImgArray(AxesMixin):
     
     def __init__(
         self,
-        obj: "da.core.Array",
+        obj: "DaskArray",
         name: str = None,
         axes: str = None,
         source: str = None, 
         metadata: dict = None
     ):
-        from dask import array as da
-        if not isinstance(obj, da.core.Array):
+        from dask.array.core import Array as DaskArray
+        if not isinstance(obj, DaskArray):
             raise TypeError(f"The first input must be dask array, got {type(obj)}")
-        self.value: "da.core.Array" = obj
+        self.value: "DaskArray" = obj
         self.source = source
         self._name = name
         self.axes = axes
@@ -53,6 +52,7 @@ class LazyImgArray(AxesMixin):
         
     @property
     def source(self):
+        """The source file path."""
         return self._source
     
     @source.setter
@@ -64,6 +64,7 @@ class LazyImgArray(AxesMixin):
     
     @property
     def name(self) -> str:
+        """Name of the array."""
         if self._name is None:
             source = self.source
             if source is None:
@@ -79,30 +80,37 @@ class LazyImgArray(AxesMixin):
     
     @property
     def metadata(self) -> dict[str, Any]:
+        """Metadata dictionary of the array."""
         return self._metadata
 
     @property
-    def ndim(self):
+    def ndim(self) -> int:
+        """Number of dimensions of the array."""
         return self.value.ndim
     
     @property
     def shape(self):
+        """Shape of the array."""
         return self.axes.tuple(self.value.shape)
         
     @property
     def dtype(self):
+        """Data type of the array"""
         return self.value.dtype
     
     @property
-    def size(self):
+    def size(self) -> int:
+        """Total number of elements in the array."""
         return self.value.size
     
     @property
     def itemsize(self):
+        """Size of each element in bytes."""
         return self.value.itemsize
     
     @property
     def chunksize(self):
+        """Chunk size of the array."""
         return self.axes.tuple(self.value.chunksize)
         
     @property
@@ -141,16 +149,19 @@ class LazyImgArray(AxesMixin):
         out._set_info(self)
         return out
     
-    @same_dtype(asfloat=True)
-    def __add__(self, other) -> LazyImgArray:
+    def _apply_operator(self, op: Callable[[Any, Any], Any], other: Any) -> LazyImgArray:
         if isinstance(other, self.__class__):
-            out = self.value + other.value
+            out = op(self.value, other.value)
         else:
-            out = self.value + other
+            out = op(self.value, other)
         out = self.__class__(out)
         out._set_info(self)
         return out
     
+    @same_dtype(asfloat=True)
+    def __add__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.add, other)
+    
     @same_dtype(asfloat=True)
     def __iadd__(self, other) -> LazyImgArray:
         if isinstance(other, self.__class__):
@@ -161,13 +172,7 @@ class LazyImgArray(AxesMixin):
     
     @same_dtype(asfloat=True)
     def __sub__(self, other) -> LazyImgArray:
-        if isinstance(other, self.__class__):
-            out = self.value - other.value
-        else:
-            out = self.value - other
-        out = self.__class__(out)
-        out._set_info(self)
-        return out
+        return self._apply_operator(operator.sub, other)
     
     @same_dtype(asfloat=True)
     def __isub__(self, other) -> LazyImgArray:
@@ -241,6 +246,33 @@ class LazyImgArray(AxesMixin):
         self.value /= other
         return self
     
+    def __gt__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.gt, other)
+    
+    def __ge__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.ge, other)
+    
+    def __lt__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.lt, other)
+    
+    def __le__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.le, other)
+    
+    def __eq__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.eq, other)
+    
+    def __ne__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.ne, other)
+    
+    def __mod__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.mod, other)
+    
+    def __floordiv__(self, other) -> LazyImgArray:
+        return self._apply_operator(operator.floordiv, other)
+    
+    def __pow__(self, power: float) -> LazyImgArray:
+        return self._apply_operator(operator.pow, power)
+
     @property
     def chunk_info(self):
         chunk_info = ", ".join([f"{s}({o})" for s, o in zip(self.chunksize, self.axes)])
@@ -264,13 +296,13 @@ class LazyImgArray(AxesMixin):
         """        
         if self.gb > Const["MAX_GB"] and not ignore_limit:
             raise MemoryError(f"Too large: {self.gb:.2f} GB")
-        arr = self.value.compute()
+        arr: xp.ndarray = self.value.compute()
         if arr.ndim > 0:
             img = xp.asnumpy(arr).view(ImgArray)
             for attr in ["_name", "_source", "axes", "_metadata"]:
                 setattr(img, attr, getattr(self, attr, None))
         else:
-            img = arr
+            img = arr.item()
         return img
     
     def release(self, update: bool = True) -> LazyImgArray:
@@ -279,13 +311,15 @@ class LazyImgArray(AxesMixin):
         again.
         """
         from dask import array as da
+
         with tempfile.NamedTemporaryFile() as ntf:
             mmap = np.memmap(ntf, mode="w+", shape=self.shape, dtype=self.dtype)
-            mmap[:] = self.value[:]
+            da.store(self.value.map_blocks(xp.asnumpy), mmap, compute=True)
+            mmap.flush()
         
         img = da.from_array(mmap, chunks=self.chunksize).map_blocks(
-            np.array, meta=np.array([], dtype=self.dtype)
-            )
+            xp.array, meta=xp.array([], dtype=self.dtype)
+        )
         if update:
             self.value = img
             out = self
@@ -483,7 +517,7 @@ class LazyImgArray(AxesMixin):
         c_axes: str = None, 
         args: tuple = None,
         kwargs: dict[str, Any] = None
-    ):
+    ) -> DaskArray:
         from dask import array as da
         if args is None:
             args = ()
@@ -507,7 +541,7 @@ class LazyImgArray(AxesMixin):
         dtype: DTypeLike = None,
         args: tuple = None,
         kwargs: dict[str, Any] = None
-    ):
+    ) -> DaskArray:
         from dask import array as da
         if args is None:
             args = ()
@@ -516,15 +550,15 @@ class LazyImgArray(AxesMixin):
         if dtype is None:
             dtype = self.dtype
         all_axes = str(self.axes)
-        def _func(input: ArrayLike, *args, **kwargs):
+        def _func(input: xp.ndarray, *args, **kwargs):
             out = xp.empty(input.shape, input.dtype)
             for sl in iter_slice(input.shape, c_axes, all_axes):
                 out[sl] = func(input[sl], *args, **kwargs)
             return out
         depth = switch_slice(c_axes, self.axes, 0, depth)
         return da.map_overlap(
-            _func, self.value, depth=depth, boundary=boundary, dtype=dtype,
-            *args, **kwargs
+            _func, self.value, *args, depth=depth, boundary=boundary, dtype=dtype,
+            **kwargs
         )
     
     def _apply_dask_filter(
@@ -689,14 +723,16 @@ class LazyImgArray(AxesMixin):
         *,
         dims: Dims = None,
         update: bool = False,
-    ):
-        # TODO: need test
+    ) -> LazyImgArray:
         depth = order
+        from functools import partial
+        func = partial(
+            _filters.spline_filter, order=order, output=np.float32, mode=mode
+        )
         return self._apply_map_overlap(
-            _filters.spline_filter,
+            func,
             c_axes=complement_axes(dims, self.axes), 
             depth=depth,
-            args=(order, np.float32, mode),
         )
     
     
@@ -766,7 +802,7 @@ class LazyImgArray(AxesMixin):
     
     @_docs.copy_docs(ImgArray.edge_filter)
     @dims_to_spatial_axes
-    @same_dtype
+    @same_dtype(asfloat=True)
     @check_input_and_output_lazy
     def edge_filter(
         self,
@@ -775,13 +811,11 @@ class LazyImgArray(AxesMixin):
         dims: Dims = None,
         update: bool = False
     ) -> LazyImgArray:
-        # BUG: returns zero array
-        from ._utils._skimage import skfil
+        from skimage.filters.edges import sobel, farid, scharr, prewitt
+
         method_dict = {
-            "sobel": (skfil.sobel, 1),
-            "farid": (skfil.farid, 2),
-            "scharr": (skfil.scharr, 1),
-            "prewitt": (skfil.prewitt, 1)
+            "sobel": (sobel, 1), "farid": (farid, 2), "scharr": (scharr, 1), 
+            "prewitt": (prewitt, 1)
         }
         try:
             filter_func, depth = method_dict[method]
@@ -803,9 +837,10 @@ class LazyImgArray(AxesMixin):
         *, 
         dims: Dims = None,
         update: bool = False
-    ) -> LazyImgArray:  
+    ) -> LazyImgArray:
+        from skimage.restoration import uft
         ndim = len(dims)
-        _, laplace_op = skres.uft.laplacian(ndim, (2*radius+1,) * ndim)
+        _, laplace_op = uft.laplacian(ndim, (2*radius+1,) * ndim)
         return self._apply_map_overlap(
             xp.ndi.convolve,
             depth=_ceilint(radius),
@@ -863,12 +898,44 @@ class LazyImgArray(AxesMixin):
             args=(gain, noise_var)
         )
     
+    @_docs.copy_docs(ImgArray.threshold)
+    @check_input_and_output_lazy
+    def threshold(
+        self,
+        thr: float | str,
+        *,
+        along: AxisLike | None = None,
+    ) -> ImgArray:
+        if self.dtype == bool:
+            return self
+        
+        from dask import array as da
+
+        if along is None:
+            along = "c" if "c" in self.axes else ""
+
+        if isinstance(thr, str) and thr.endswith("%"):
+            p = float(thr[:-1].strip())
+            out = da.zeros(self.shape, dtype=bool)
+            for sl, img in self.iter(along):
+                thr = da.percentile(img, p)
+                out[sl] = img >= thr
+                
+        elif np.isscalar(thr) or (hasattr(thr, "compute") and thr.ndim == 0):
+            out = self >= thr
+        else:
+            raise TypeError(
+                "'thr' must be a scalar or string in 'X%' format."
+            )
+        return out
+    
     @_docs.copy_docs(ImgArray.fft)
     @dims_to_spatial_axes
     @check_input_and_output_lazy
     def fft(self, *, shape: int | Iterable[int] | str = "same", shift: bool = True, 
             dims: Dims = None) -> LazyImgArray:
         from dask import array as da
+
         axes = [self.axisof(a) for a in dims]
         if shape == "square":
             s = 2**int(np.ceil(np.max(self.sizesof(dims))))
@@ -877,7 +944,8 @@ class LazyImgArray(AxesMixin):
             shape = None
         else:
             shape = check_nd(shape, len(dims))
-        freq = da.fft.fftn(self.value.astype(np.float32), s=shape, axes=axes).astype(np.complex64)
+        fft = _get_fft_func(Const["RESOURCE"])
+        freq = fft(self.value.astype(np.float32), s=shape, axes=axes)
         if shift:
             freq[:] = da.fft.fftshift(freq, axes=axes)
         return freq
@@ -885,14 +953,16 @@ class LazyImgArray(AxesMixin):
     @_docs.copy_docs(ImgArray.ifft)
     @dims_to_spatial_axes
     @check_input_and_output_lazy
-    def ifft(self, real:bool=True, *, shift:bool=True, dims=None) -> LazyImgArray:
+    def ifft(self, real: bool = True, *, shift: bool = True, dims: Dims = None) -> LazyImgArray:
         from dask import array as da
+
         axes = [self.axisof(a) for a in dims]
         if shift:
             freq = da.fft.ifftshift(self.value, axes=axes)
         else:
             freq = self.value
-        out = da.fft.ifftn(freq, axes=axes).astype(np.complex64)
+        ifft = _get_ifft_func(Const["RESOURCE"])
+        out = ifft(freq, axes=axes)
         
         if real:
             out = da.real(out)
@@ -905,26 +975,35 @@ class LazyImgArray(AxesMixin):
     def power_spectra(self, shape = "same", norm: bool = False, zero_norm: bool = False, *,
                       dims: Dims = None) -> LazyImgArray:
         freq = self.fft(dims=dims, shape=shape)
-        pw = freq.value.real**2 + freq.value.imag**2
+        pw = freq.value.real ** 2 + freq.value.imag ** 2
         if norm:
             pw /= pw.max()
         if zero_norm:
-            sl = switch_slice(dims, pw.axes, ifin=np.array(pw.shape)//2, ifnot=slice(None))
+            sl = switch_slice(dims, self.axes, ifin=np.array(self.shape)//2, ifnot=slice(None))
             pw[sl] = 0
         return pw
     
     def chunksizeof(self, axis:str):
+        """Get the chunk size of the given axis"""
         return self.value.chunksize[self.axes.find(axis)]
     
     def chunksizesof(self, axes:str):
+        """Get the chunk sizes of the given axes"""
         return tuple(self.chunksizeof(a) for a in axes)
         
-    def transpose(self, axes):
-        new_axes = [self.axes[i] for i in list(axes)]
-        out = self.__class__(self.value.transpose(axes))
+    @_docs.copy_docs(ImgArray.transpose)
+    def transpose(self, axes=None):
+        if axes is None:
+            _axes = None
+            new_axes = self.axes[::-1]
+        else:
+            _axes = [self.axisof(a) for a in axes]
+            new_axes = [self.axes[i] for i in list(axes)]
+        out = self.__class__(self.value.transpose(_axes))
         out._set_info(self, new_axes=new_axes)
         return out
     
+    @_docs.copy_docs(ImgArray.sort_axes)
     def sort_axes(self):
         order = self.axes.argsort()
         return self.transpose(tuple(order))
@@ -979,6 +1058,7 @@ class LazyImgArray(AxesMixin):
         return out
     
     @_docs.copy_docs(ImgArray.proj)
+    @same_dtype
     def proj(self, axis: str = None, method: str = "mean") -> LazyImgArray:
         from dask import array as da
         if axis is None:
@@ -999,7 +1079,8 @@ class LazyImgArray(AxesMixin):
     @_docs.copy_docs(ImgArray.binning)
     @dims_to_spatial_axes
     @same_dtype
-    def binning(self, binsize: int = 2, method = "mean", *, check_edges: bool = True, dims: Dims = None) -> LazyImgArray:
+    def binning(self, binsize: int = 2, method = "mean", *, check_edges: bool = True, 
+                dims: Dims = None) -> LazyImgArray:
         if binsize == 1:
             return self
         
@@ -1022,7 +1103,7 @@ class LazyImgArray(AxesMixin):
         return out
     
     @_docs.copy_docs(ImgArray.track_drift)
-    def track_drift(self, along: str = None, upsample_factor: int = 10) -> "da.core.Array":
+    def track_drift(self, along: str = None, upsample_factor: int = 10) -> "DaskArray":
         if along is None:
             along = find_first_appeared("tpzc<i", include=self.axes)
         elif len(along) != 1:
@@ -1080,7 +1161,7 @@ class LazyImgArray(AxesMixin):
         elif len(along) != 1:
             raise ValueError("`along` must be single character.")
         
-        from ..frame import MarkerFrame
+        from impy.frame import MarkerFrame
         
         if shift is None:
             # determine 'ref'
@@ -1129,61 +1210,167 @@ class LazyImgArray(AxesMixin):
         
         return out
     
+    
+    @_docs.copy_docs(ImgArray.radon)
+    @dims_to_spatial_axes
+    def radon(
+        self,
+        degrees: float | Iterable[float], 
+        *,
+        central_axis: AxisLike | Sequence[float] | None = None,
+        order: int = 3,
+        dims: Dims = None,
+    ) -> LazyImgArray:
+        from dask import array as da
+        from dask_image.ndinterp import affine_transform
+        
+        params, output_shape, squeeze = _transform.normalize_radon_input(
+            self, dims, central_axis, degrees
+        )
+
+        # apply spline filter in advance.
+        input = self.as_float().spline_filter(order=order)
+        tasks: list[DaskArray] = [
+            affine_transform(
+                input.value, p, order=order, output_shape=output_shape, prefilter=False
+            ).sum(axis=0)
+            for p in params
+        ]
+        out = LazyImgArray(da.stack(tasks, axis=0))
+        out._set_info(self, self.axes.drop(0).insert(0, "degree"))
+        out.axes[0].labels = list(degrees)
+        if squeeze:
+            out = out[0]
+        return out
+    
+    @_docs.copy_docs(ImgArray.iradon)
+    def iradon(
+        self,
+        degrees: Sequence[float],
+        *,
+        central_axis: AxisLike = "y",
+        degree_axis: AxisLike | None = None,
+        height_axis: AxisLike | None = None,
+        height: int | None = None,
+        window: str = "hamming",
+        order: int = 3,
+    ) -> LazyImgArray:
+        from dask import delayed, array as da
+        
+        interp = {0: "nearest", 1: "linear", 3: "cubic"}[order]
+        central_axis, degree_axis, output_shape, new_axes = _transform.normalize_iradon_input(
+            self, central_axis, height_axis, degree_axis, height
+        )
+        input = np.moveaxis(self.value, self.axisof(degree_axis), -1)
+        filter_func = _transform.get_fourier_filter(input.shape[-2], window)
+        
+        func = delayed(_transform.iradon)
+        if self.ndim == 3:
+            arrays = [
+                da.from_delayed(
+                    func(
+                        image_slice,
+                        degrees=degrees,
+                        interpolation=interp,
+                        filter_func=filter_func,
+                        output_shape=output_shape,
+                    ),
+                    shape=self.shape[1:],
+                    dtype=self.dtype,
+                )
+                for image_slice in input
+            ]
+            
+            out = da.stack(arrays, axis=0)
+            out = np.moveaxis(out, 0, 1)
+        else:
+            out = da.from_delayed(
+                func(
+                    input,
+                    degrees=degrees,
+                    interpolation=interp,
+                    filter_func=filter_func,
+                    output_shape=output_shape,
+                ),
+                shape=output_shape,
+                dtype=self.dtype,
+            )
+        out = out[::-1]
+        out = self.__class__(out, axes=new_axes, name=self.name, source=self.source)
+        out._set_info(self, new_axes=new_axes)
+        return out
+        
     @_docs.copy_docs(ImgArray.pad)
     @dims_to_spatial_axes
     @check_input_and_output_lazy
-    def pad(self, pad_width, mode: str = "constant", *, dims: Dims = None, **kwargs) -> LazyImgArray:
+    def pad(
+        self, 
+        pad_width: int | tuple[int, int] | Sequence[tuple[int, int]],
+        mode: str = "constant",
+        *,
+        dims: Dims = None,
+        **kwargs,
+    ) -> LazyImgArray:
         pad_width = _misc.make_pad(pad_width, dims, self.axes, **kwargs)
         padimg = np.pad(self.value, pad_width, mode, **kwargs)
         return padimg
     
-    # @_docs.copy_docs(ImgArray.wiener)
-    # @dims_to_spatial_axes
-    # @same_dtype(asfloat=True)
-    # @record_lazy
-    # def wiener(self, psf: np.ndarray, lmd: float = 0.1, *, depth="auto", dims: Dims = None, update: bool = False) -> LazyImgArray:
-    #     if lmd <= 0:
-    #         raise ValueError(f"lmd must be positive, but got: {lmd}")
+    @_docs.copy_docs(ImgArray.wiener)
+    @same_dtype(asfloat=True)
+    @check_input_and_output_lazy
+    @dims_to_spatial_axes
+    def wiener(
+        self,
+        psf: np.ndarray,
+        lmd: float = 0.1,
+        *,
+        dims: Dims = None,
+        update: bool = False,
+    ) -> LazyImgArray:
+        if lmd <= 0:
+            raise ValueError(f"lmd must be positive, but got: {lmd}")
         
-    #     if depth == "auto":
-    #         depth = 32  # TODO: any better way?
+        psf_ft, psf_ft_conj = _deconv.check_psf(self, psf, dims)
         
-    #     psf_ft, psf_ft_conj = _deconv.check_psf(self, psf, dims)
-        
-    #     return self._apply_map_overlap
-    #     return self._apply_function(_deconv.wiener, 
-    #                       c_axes=complement_axes(dims, self.axes),
-    #                       rechunk_to="max",
-    #                       args=(psf_ft, psf_ft_conj, lmd)
-    #                       )
+        return self._apply_function(
+            _deconv.wiener, 
+            c_axes=complement_axes(dims, self.axes),
+            args=(psf_ft, psf_ft_conj, lmd)
+        )
     
-    # @_docs.copy_docs(ImgArray.lucy)
-    # @dims_to_spatial_axes
-    # @same_dtype(asfloat=True)
-    # @record_lazy
-    # def lucy(self, psf: np.ndarray, niter: int = 50, eps: float = 1e-5, depth: int = 32, *, dims: Dims = None, 
-    #          update: bool = False) -> LazyImgArray:
-    #     psf_ft, psf_ft_conj = _deconv.check_psf(self, psf, dims)
+    @_docs.copy_docs(ImgArray.lucy)
+    @same_dtype(asfloat=True)
+    @check_input_and_output_lazy
+    @dims_to_spatial_axes
+    def lucy(
+        self,
+        psf: np.ndarray,
+        niter: int = 50,
+        eps: float = 1e-5,
+        *,
+        dims: Dims = None, 
+        update: bool = False,
+    ) -> LazyImgArray:
+        psf_ft, psf_ft_conj = _deconv.check_psf(self, psf, dims)
 
-    #     return self._apply_map_overlap(_deconv.richardson_lucy, 
-    #                       c_axes=complement_axes(dims, self.axes),
-    #                       depth=depth,
-    #                       boundary="nearest",
-    #                       args=(psf_ft, psf_ft_conj, niter, eps)
-    #                       )
+        return self._apply_function(
+            _deconv.richardson_lucy, 
+            c_axes=complement_axes(dims, self.axes),
+            args=(psf_ft, psf_ft_conj, niter, eps)
+        )
     
     def __array_function__(self, func, types, args, kwargs):
         """
         Every time a numpy function (np.mean...) is called, this function will be called. Essentially numpy
         function can be overloaded with this method.
         """
-        from dask import array as da
+        from dask.array.core import Array as DaskArray
         args, kwargs = _replace_inputs(self, args, kwargs)
         
         _types = []
         for t in types:
             if t is self.__class__:
-                _types.append(da.core.Array)
+                _types.append(DaskArray)
             else:
                 _types.append(t)
         
@@ -1195,7 +1382,7 @@ class LazyImgArray(AxesMixin):
         if isinstance(result, (tuple, list)):
             out = []
             for r in result:
-                if isinstance(r, da.core.Array):
+                if isinstance(r, DaskArray):
                     out.append(
                         self.__class__(r)._process_output(self, args, kwargs)
                     )
@@ -1203,7 +1390,7 @@ class LazyImgArray(AxesMixin):
                     out.append(r)
             out = DataList(out)
             
-        elif isinstance(result, da.core.Array):
+        elif isinstance(result, DaskArray):
             out = self.__class__(result)
             out._process_output(self, args, kwargs)
             
@@ -1295,7 +1482,26 @@ class LazyImgArray(AxesMixin):
         else:
             raise ValueError(f"dtype: {dtype}")
     
+    @_docs.copy_docs(ImgArray.mean)
+    def mean(self, axis=None, keepdims=False, **kwargs):
+        return np.mean(self, axis=axis, keepdims=keepdims, **kwargs)
     
+    @_docs.copy_docs(ImgArray.std)
+    def std(self, axis=None, keepdims=False, **kwargs):
+        return np.std(self, axis=axis, keepdims=keepdims, **kwargs)
+    
+    @_docs.copy_docs(ImgArray.sum)
+    def sum(self, axis=None, keepdims=False, **kwargs):
+        return np.sum(self, axis=axis, keepdims=keepdims, **kwargs)
+    
+    @_docs.copy_docs(ImgArray.max)
+    def max(self, axis=None, keepdims=False, **kwargs):
+        return np.max(self, axis=axis, keepdims=keepdims, **kwargs)
+    
+    @_docs.copy_docs(ImgArray.min)
+    def min(self, axis=None, keepdims=False, **kwargs):
+        return np.min(self, axis=axis, keepdims=keepdims, **kwargs)
+
     def _set_additional_props(self, other):
         # set additional properties
         # If `other` does not have it and `self` has, then the property will be inherited.
@@ -1364,4 +1570,25 @@ def iter_slice(shape, iteraxes: str, all_axes: str, exclude: str = ""):
     # if iterlist = []
     if c == 0:
         outsl = (slice(None),) * (len(all_axes) - len(exclude))
-        yield outsl
\ No newline at end of file
+        yield outsl
+
+# NOTE: following FFT functions needs the "resource" argument to make it work with both
+# numpy and cupy.
+@lru_cache
+def _get_fft_func(resource) -> Callable[[DaskArray], DaskArray]:
+    """Get the scipy FFT function for dask."""
+    from array_api import scipy_fft
+    from dask import array as da
+    
+    return da.fft.fft_wrap(scipy_fft.fftn)
+
+@lru_cache
+def _get_ifft_func(resource) -> Callable[[DaskArray], DaskArray]:
+    """Get the scipy IFFT function for dask."""
+    from array_api import scipy_fft
+    from dask import array as da
+    
+    return da.fft.fft_wrap(scipy_fft.ifftn)
+
+
+    
\ No newline at end of file
